@@ -1,10 +1,9 @@
 {-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE TemplateHaskell #-}
 
 -- |
 -- Module      :  Analyze.Analyze
 -- Description :  Parse sequence file formats and analyze them
--- Copyright   :  (c) Dominik Schrempf 2018
+-- Copyright   :  2021 Dominik Schrempf
 -- License     :  GPL-3.0-or-later
 --
 -- Maintainer  :  dominik.schrempf@gmail.com
@@ -17,14 +16,14 @@ module SLynx.Translate.Translate
   )
 where
 
-import Control.Monad.Logger
-import Control.Monad.Trans.Reader (ask)
-import qualified Data.Text as T
-import ELynx.Data.Character.Codon
-import ELynx.Data.Sequence.Sequence
-import ELynx.Data.Sequence.Translate
-import ELynx.Export.Sequence.Fasta
-import ELynx.Tools
+import Control.Monad.Trans.Reader
+import ELynx.Character.Codon
+import ELynx.Sequence.Export.Fasta
+import ELynx.Sequence.Sequence
+import ELynx.Sequence.Translate
+import ELynx.Tools.ELynx
+import ELynx.Tools.Environment
+import ELynx.Tools.Logger
 import SLynx.Tools
 import SLynx.Translate.Options
 
@@ -34,11 +33,10 @@ translateSeqs rf uc = map (translateSeq uc rf)
 -- | Translate sequences.
 translateCmd :: ELynx TranslateArguments ()
 translateCmd = do
-  (TranslateArguments al inFile rf uc) <- local <$> ask
-  $(logInfo) "Command: Translate sequences to amino acids."
-  $(logInfo) $ T.pack $ "  Universal code: " <> show uc <> "."
-  $(logInfo) $ T.pack $ "  Reading frame: " <> show rf <> "."
-  $(logInfo) ""
+  (TranslateArguments al inFile rf uc) <- localArguments <$> ask
+  logInfoS $ "  Universal code: " <> show uc <> "."
+  logInfoS $ "  Reading frame: " <> show rf <> "."
+  logInfoS ""
   ss <- readSeqs al inFile
   let result = sequencesToFasta $ translateSeqs rf uc ss
   out "translated sequences" result "fasta"
